@@ -1,9 +1,11 @@
 from .ColorScales import ColorScales
 from .Select import Select
+from .SmartNodeSelector import SmartNodeSelector
 from .WebvizPluginPlaceholder import WebvizPluginPlaceholder
 
 __all__ = [
     "ColorScales",
     "Select",
+    "SmartNodeSelector",
     "WebvizPluginPlaceholder"
 ]
\ No newline at end of file
